@@ -2,7 +2,7 @@
 
 __author__ = 'Tormod Haugland'
 __email__ = 'tormod.haugland@gmail.com'
-__version__ = '0.1.0'
+__version__ = '__version__ = '0.1.1''
 
 
-__all__ = ['globals']
+__all__ = ['globals', 'models', 'parsing', 'exceptions']
